import gettext
from indicatorBug.helpers import load_settings, save_settings
from indicatorBug import prompts
from gi.repository import Gtk, GObject, GdkPixbuf
_ = gettext.gettext
gettext.textdomain('indicator-bug')


class PreferencesDialog(Gtk.Dialog):

    def __init__(self, connection, logger):
        GObject.GObject.__init__(self)
        self.launchpad = connection
        self.log=logger
        self.builder = Gtk.Builder()
        self.builder.set_translation_domain('indicator-bug')
        self.builder.add_from_file('/usr/share/indicator-bug/ui/Preferences.glade')
        self.builder.connect_signals(self)
        self.dialog = self.builder.get_object('PreferencesDialog')

        #Get Widgets
        self.account_form = self.builder.get_object('AccountForm')

        #Get Form Elements
        self.project_name_form = self.builder.get_object('project_name_form')
        self.project_name_image = self.builder.get_object('project_name_image')
        self.tags_form = self.builder.get_object('tags_form')
        self.tags_image = self.builder.get_object('tags_image')
        self.importance_form = self.builder.get_object('importance_form')
        self.checkbuttonUndecided = self.builder.get_object('checkbuttonUndecided')
        self.checkbuttonMedium = self.builder.get_object('checkbuttonMedium')
        self.checkbuttonWishlist = self.builder.get_object('checkbuttonWishlist')
        self.checkbuttonHigh = self.builder.get_object('checkbuttonHigh')
        self.checkbuttonLow = self.builder.get_object('checkbuttonLow')
        self.checkbuttonCritical = self.builder.get_object('checkbuttonCritical')
        self.checkbuttonNew = self.builder.get_object('checkbuttonNew')
        self.checkbuttonIncomplete = self.builder.get_object('checkbuttonIncomplete')
        self.checkbuttonConfirmed = self.builder.get_object('checkbuttonConfirmed')
        self.checkbuttonTriaged = self.builder.get_object('checkbuttonTriaged')
        self.checkbuttonInProgress = self.builder.get_object('checkbuttonInProgress')
        self.checkbuttonFixCommited = self.builder.get_object('checkbuttonFixCommited')
        self.buttonOk = self.builder.get_object('buttonOk')
        self.buttonCancel = self.builder.get_object('buttonCancel')

        self.settings = {}
        self.load_settings()
        self.project=self.launchpad.projects[self.project_name_form.get_text()]

    def run(self):
        self.log.debug("running prefs")
        self.dialog.show()

    def validate_project_name(self, widget=None, data=None):
        project_name=self.project_name_form.get_text()
        try:
            self.log.debug("validating project name...")
            self.project = self.launchpad.projects[project_name]
            return True
        except(KeyError):
            self.log.error("Incorrect project name")
            error_msg = "Project '" + project_name + "' was not found on Launchpad.\nPlease enter a valid project name."
            prompts.error(self.dialog, _("Error occured!"), _(error_msg))
            return False

    def load_settings(self):
        self.log.debug("loading settings from file...")
        self.settings = load_settings()
        self.project_name_form.set_text(self.settings['project_name'])
        self.tags_form.set_text(self.settings['tags'])
        self.checkbuttonUndecided.set_active(self.settings['checkbuttonUndecided'])
        self.checkbuttonMedium.set_active(self.settings['checkbuttonMedium'])
        self.checkbuttonWishlist.set_active(self.settings['checkbuttonWishlist'])
        self.checkbuttonHigh.set_active(self.settings['checkbuttonHigh'])
        self.checkbuttonLow.set_active(self.settings['checkbuttonLow'])
        self.checkbuttonCritical.set_active(self.settings['checkbuttonCritical'])
        self.checkbuttonNew.set_active(self.settings['checkbuttonNew'])
        self.checkbuttonIncomplete.set_active(self.settings['checkbuttonIncomplete'])
        self.checkbuttonTriaged.set_active(self.settings['checkbuttonTriaged'])
        self.checkbuttonInProgress.set_active(self.settings['checkbuttonInProgress'])
        self.checkbuttonFixCommited.set_active(self.settings['checkbuttonFixCommited'])
        self.checkbuttonConfirmed.set_active(self.settings['checkbuttonConfirmed'])

    #Signals
    def on_account_save(self, widget, data=None):
        self.log.debug("saving preference changes...")
        if self.validate_project_name():
            preferences = {
                'project_name': self.project_name_form.get_text(),
                'tags': self.tags_form.get_text(),
                'checkbuttonUndecided': self.checkbuttonUndecided.get_active(),
                'checkbuttonMedium': self.checkbuttonMedium.get_active(),
                'checkbuttonWishlist': self.checkbuttonWishlist.get_active(),
                'checkbuttonHigh': self.checkbuttonHigh.get_active(),
                'checkbuttonLow': self.checkbuttonLow.get_active(),
                'checkbuttonCritical': self.checkbuttonCritical.get_active(),
                'checkbuttonNew': self.checkbuttonNew.get_active(),
                'checkbuttonIncomplete': self.checkbuttonIncomplete.get_active(),
                'checkbuttonConfirmed': self.checkbuttonConfirmed.get_active(),
                'checkbuttonTriaged': self.checkbuttonTriaged.get_active(),
                'checkbuttonInProgress': self.checkbuttonInProgress.get_active(),
                'checkbuttonFixCommited': self.checkbuttonFixCommited.get_active()
            }
            self.settings = preferences
            save_settings(self.settings)
            self.dialog.hide()
            self.load_settings()
            self.emit("data-change", 0)
            return True

    def on_about_dialog(self, widget, data=None):
        self.log.debug("running about dialog...")
        widget.set_sensitive(False)
        ad = Gtk.AboutDialog()
        ad.set_transient_for(self.dialog)
        ad.set_name(_("Indicator-Bug"))
        ad.set_version("0.2")
        icon = GdkPixbuf.Pixbuf.new_from_file('/usr/share/pixmaps/indicator-bug.png')
        ad.set_logo(icon)
        ad.set_copyright('Copyright (c) 2011\nOier Mees')
        ad.set_comments(_('A bug indicator for Launchpad projects'))
        ad.set_license(_(''+
            'This program is free software: you can redistribute it and/or modify it\n'+
            'under the terms of the GNU General Public License as published by the\n'+
            'Free Software Foundation, either version 3 of the License, or (at your option)\n'+
            'any later version.\n\n'+
            'This program is distributed in the hope that it will be useful, but\n'+
            'WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n'+
            'or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for\n'+
            'more details.\n\n'+
            'You should have received a copy of the GNU General Public License along with\n'+
            'this program.  If not, see <http://www.gnu.org/licenses/>.'))
        ad.set_website('http://www.launchpad.net/indicator-bug')
        ad.set_website_label('http://www.launchpad.net/indicator-bug')
        ad.set_authors(['Oier Mees <oier.mees@gmail.com>'])
        # Launchpad does this automatically for translations
        # typed in Launchpad. This is a special string shown
        # in the 'About' box.
        ad.set_translator_credits(_("translator-credits"))
        ad.set_program_name(_("Indicator-Bug"))
        ad.run()
        ad.destroy()
        widget.set_sensitive(True)

    def on_delete(self, widget, data=None):
        self.dialog.hide()
        return True


def new_signal(label, class_name, flag=GObject.SignalFlags.ACTION, ret=None, args=(int,)):
    GObject.signal_new(label, class_name, flag, ret, args)

new_signal("data-change", PreferencesDialog)

