#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2011 Oier Mees oier.mees@ogmail.com
#
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

###################### DO NOT TOUCH THIS (HEAD TO THE SECOND PART) ######################
VERSION = '0.1'

import os
import sys

try:
    import DistUtilsExtra.auto
except ImportError:
    print >> sys.stderr, 'To build indicator-bug you need https://launchpad.net/python-distutils-extra'
    sys.exit(1)
assert DistUtilsExtra.auto.__version__ >= '2.18', 'needs DistUtilsExtra.auto >= 2.18'

def update_data_path(prefix, oldvalue=None):

    try:
        fin = file('indicatorBug/indicator-bug-config.py', 'r')
        fout = file(fin.name + '.new', 'w')
        for line in fin:            
            fields = line.split(' = ') # Separate variable from value
            if fields[0] == '__indicatorBug_data_directory__':
                # update to prefix, store oldvalue
                if not oldvalue:
                    oldvalue = fields[1]
                    line = "%s = '%s'\n" % (fields[0], prefix)
                else: # restore oldvalue
                    line = "%s = %s" % (fields[0], oldvalue)
            # update version if we forget it
            elif fields[0] == '__version__':
                line = "%s = '%s'\n" % (fields[0], VERSION)
            fout.write(line)

        fout.flush()
        fout.close()
        fin.close()
        os.rename(fout.name, fin.name)
    except (OSError, IOError), e:
        print ("ERROR: Can't find indicatorBug/indicator-bug-config.py")
        sys.exit(1)
    return oldvalue


def update_desktop_file(datadir):
    try:
        fin = file('indicator-bug.desktop.in', 'r')
        fout = file(fin.name + '.new', 'w')

        for line in fin:            
            if 'Icon=' in line:
                line = "Icon=%s\n" % ('indicator-bug')
            fout.write(line)
        fout.flush()
        fout.close()
        fin.close()
        os.rename(fout.name, fin.name)
    except (OSError, IOError), e:
        print ("ERROR: Can't find indicator-bug.desktop.in")
        sys.exit(1)


class InstallAndUpdateDataDirectory(DistUtilsExtra.auto.install_auto):
    def run(self):
        if self.root or self.home:
            print "WARNING: You don't use a standard --prefix installation, take care that you eventually " \
            "need to indicator-bug/indicator-bug-config.py file to adjust __indicatorBug_data_directory__. You can " \
            "ignore this warning if you are packaging and uses --prefix."
        previous_value = update_data_path(self.prefix + '/share/indicator-bug/')
        update_desktop_file(self.prefix + '/share/indicator-bug/')
        DistUtilsExtra.auto.install_auto.run(self)
        update_data_path(self.prefix, previous_value)


        
##################################################################################
###################### YOU SHOULD MODIFY ONLY WHAT IS BELOW ######################
##################################################################################
import glob

DistUtilsExtra.auto.setup(
    name='indicator-bug',
    version="'%s'" % VERSION,
    license='GPL-3',
    author='Oier Mees',
    author_email='oier.mees@gmail.com',
    description='Lists bugs from a Launchpad project in an indicator',
    url='https://launchpad.net/indicator-bug',
    long_description="""Indicator-Bug lists bugs from a Launchpad project in an indicator and updates it regularly. It supports Launchpads' usual advanced bug searching options. Clicking on a bug opens the bugs page on a browser.""",
    scripts=['indicator-bug'] ,
    data_files = [
        ('/usr/share/icons/ubuntu-mono-dark/status/24', glob.glob('data/icons/*.svg')),
        ('/usr/share/icons/ubuntu-mono-dark/status/22', glob.glob('data/icons/*.svg')),
        ('/usr/share/pixmaps',['data/icons/indicator-bug.png']),
        ('/usr/share/apport/package-hooks', ['source_indicator-bug.py'])
    ],
    cmdclass={'install': InstallAndUpdateDataDirectory}
    )

